@@ -4,7 +4,7 @@
 void gcmpwpvis (int *pop,
             int *K,
             int *n,
-            int *samplesize, int *burnin, int *interval,
+            int *samplesize, int *warmup, int *interval,
             double *mu, double *dfmu,
             double *sigma, double *dfsigma,
             double *lnlam, double *nu,
@@ -29,8 +29,8 @@ void gcmpwpvis (int *pop,
             double *posu,
             double *posd,
             double *lpriorm,
-            int *burnintheta,
-            int *burninbeta,
+            int *warmuptheta,
+            int *warmupbeta,
             int *verbose
                          );
 
@@ -47,7 +47,7 @@ void MHwpmem (int *u, int *n, int *K,
             double *lmemmuproposal, double *memnuproposal, 
             double *beta0sample, double *betatsample, double *betausample,
             double *lmemmusample, double *memnusample,
-            int *samplesize, int *staken, int *burnin, int *interval,
+            int *samplesize, int *staken, int *warmup, int *interval,
             int *verbose
          );
 			 
@@ -58,7 +58,7 @@ void MHcmptheta (int *Nk, int *K,
             double *nuproposal, 
             int *N, int *Npi, double *psample,
             double *lnlamsample, double *nusample,
-            int *samplesize, int *staken, int *burnintheta, int *interval,
+            int *samplesize, int *staken, int *warmuptheta, int *interval,
             int *verbose
          );
 
