@@ -11,7 +11,7 @@ void gplndisease (int *pop, int *dis,
             int *nk0, int *nk1, 
             int *K, 
             int *n, 
-            int *samplesize, int *burnin, int *interval,
+            int *samplesize, int *warmup, int *interval,
             double *mu0, double *mu1, double *kappa0, 
             double *sigma0,  double *sigma1, double *df0,
 	    int *Np0, int *Np1,
@@ -22,12 +22,12 @@ void gplndisease (int *pop, int *dis,
             double *p0pos, double *p1pos, 
             double *ppos, 
 	    double *lpriorm,
-            int *burnintheta,
+            int *warmuptheta,
             int *verbose
               ) {
   int dimsample, Nnp0, Nnp1;
   int step, staken, getone=1, intervalone=1, verboseMHdisease = 0;
-  int i, ni, Ni, Ki, isamp, iinterval, isamplesize, iburnin;
+  int i, ni, Ni, Ki, isamp, iinterval, isamplesize, iwarmup;
   double mu0i, mu1i, pbeta, beta, sigma0i, sigma1i, dsamp;
   double dkappa0, ddf0, dmu0, dmu1, dsigma0, dsigma1, dmuproposal, dsigmaproposal;
   int tU, popi, imaxN, imaxm, itotdis0, itotdis;
@@ -42,7 +42,7 @@ void gplndisease (int *pop, int *dis,
   imaxm=imaxN-ni;
   isamplesize=(*samplesize);
   iinterval=(*interval);
-  iburnin=(*burnin);
+  iwarmup=(*warmup);
   Nnp0=(*Np0);
   Nnp1=(*Np1);
   dkappa0=(*kappa0);
@@ -67,9 +67,9 @@ void gplndisease (int *pop, int *dis,
   double *pdeg0i = (double *) malloc(sizeof(double) * Nnp0);
   double *pdeg1i = (double *) malloc(sizeof(double) * Nnp1);
   double *psample = (double *) malloc(sizeof(double) * (Nnp0+Nnp1));
-  double *musample = (double *) malloc(sizeof(double) * 2);
-  double *betasample = (double *) malloc(sizeof(double));
-  double *sigmasample = (double *) malloc(sizeof(double) * 2);
+  double *musample = (double *) malloc(sizeof(double) * isamplesize);
+  double *betasample = (double *) malloc(sizeof(double) * isamplesize);
+  double *sigmasample = (double *) malloc(sizeof(double) * isamplesize);
 
   b[ni-1]=pop[ni-1];
   for (i=(ni-2); i>=0; i--){
@@ -113,14 +113,14 @@ void gplndisease (int *pop, int *dis,
   sigmasample[1] = dsigma1;
 
   isamp = 0;
-  step = -iburnin;
+  step = -iwarmup;
   while (isamp < isamplesize) {
     /* Draw new theta */
     MHplndisease(Nk0,Nk1,&itotdis,K,mu0,mu1,kappa0,sigma0,sigma1,df0,
           muproposal, sigmaproposal,
 	  &Ni, &Nnp0, &Nnp1, psample, 
 	  musample, betasample, sigmasample, &getone, &staken, 
-	  burnintheta, &intervalone, 
+	  warmuptheta, &intervalone, 
 	  &verboseMHdisease);
 
     beta=betasample[0];
@@ -339,12 +339,12 @@ void MHplndisease (int *Nk0, int *Nk1, int *totdis, int *K,
             double *sigmaproposal, 
             int *N, int *Np0, int *Np1, double *psample,
             double *musample, double *betasample, double *sigmasample,
-            int *samplesize, int *staken, int *burnin, int *interval,
+            int *samplesize, int *staken, int *warmup, int *interval,
 	    int *verbose
 			 ) {
   int Nnp0, Nnp1;
   int step, taken, give_log1=1;
-  int i, Ki, Ni, isamp, iinterval, isamplesize, iburnin, itotdis;
+  int i, Ki, Ni, isamp, iinterval, isamplesize, iwarmup, itotdis;
   double ip, cutoff;
   double mu0star, mu1star, mu0i, mu1i, lp;
   double pbeta, betastar, betai;
@@ -377,7 +377,7 @@ void MHplndisease (int *Nk0, int *Nk1, int *totdis, int *K,
   Ni=(*N);
   isamplesize=(*samplesize);
   iinterval=(*interval);
-  iburnin=(*burnin);
+  iwarmup=(*warmup);
   dkappa0=(*kappa0);
   rkappa0=sqrt(dkappa0);
   ddf0=(*df0);
@@ -393,7 +393,7 @@ void MHplndisease (int *Nk0, int *Nk1, int *totdis, int *K,
 
   // First set starting values
   isamp = taken = 0;
-  step = -iburnin;
+  step = -iwarmup;
   betai = betasample[0];
   p0is=1.;
   p1is=1.;
@@ -457,7 +457,7 @@ void MHplndisease (int *Nk0, int *Nk1, int *totdis, int *K,
     p1i[i]=pdeg1i[i];
   }
 
-  // Now do the MCMC updates (starting with the burnin updates)
+  // Now do the MCMC updates (starting with the warmup updates)
   while (isamp < isamplesize) {
 //  Rprintf("step %d Ni %d itotdis %d isamp %d\n", step, Ni, itotdis, isamp);
     /* Propose new theta */
